@@ -3,7 +3,6 @@
 #' @author Marc Girondot
 #' @return None
 #' @param textinfo Text to display in the growlnotify window
-#' @param help If TRUE, an help is displayed
 #' @description This function is used to send a notification to MacOS user.
 #' @examples 
 #' # If growlnotify is used on a non-mac system, it just quits.
@@ -12,12 +11,7 @@
 
 
 growlnotify <-
-function(textinfo="", help=FALSE) {
-if(help) {
-	cat("This function is used to send a notification to Mac user.\n")
-	cat("The syntax is growlnotify(textinfo='Done!')\n")
-
-} else {
+function(textinfo="") {
 	if (.Platform$OS.type=="unix") {
 		if (substr(.Platform$pkgType, 1, 3)=="mac") {
 			if (any(system("ls /usr/local/bin/", intern=TRUE)=="growlnotify")) {
@@ -26,4 +20,3 @@ if(help) {
 		}
 	}
 }
-}
